from science_signal.signal import Signal # type: ignore[reportMissingTypeStubs]
from backscattering_analyzer import logger

from numpy.typing import NDArray
from numpy import float64, sqrt


def process_movement(
    bench: Signal,
    mirror: Signal,
    calibrations: dict[str, float],
    vibration_frequency: float,
) -> Signal:
    """
    Clean and compute relative movement between the bench and the mirror
    """
    logger.debug(_("computing relative movement"))

    return (
        (
            bench * calibrations["bench"]
            - mirror * calibrations["mirror"]
        )
        .detrend("constant")
        .filter(end=1)
        .detrend("constant")
    )


def compute_light(
    pre_scatter_factor: float | None,
    factor_n: Signal,
    coupling_n: Signal,
    factor_d: Signal,
    coupling_d: Signal,
    phase: float,
) -> NDArray[float64]:
    """
    Optimized computing of light with pre-computed factor
    """
    if pre_scatter_factor is None:
        raise Exception(_(
            "Cannot compute projection without backscattering factor"
        ))
    return (
        sqrt(pre_scatter_factor)
        / phase
        * (coupling_n * factor_n + coupling_d * factor_d).y
    ) # type: ignore[reportAny]
